@@ -23,8 +23,8 @@
                                | Pick a window, Jimmy, you're leaving.
                                */
 
-/** \file buf.c Buffers that map between stdio file streams and librsync
- * streams.
+/** \file buf.c
+ * Buffers that map between stdio file streams and librsync streams.
  *
  * As the stream consumes input and produces output, it is refilled from
  * appropriate input and output FILEs. A dynamically allocated buffer of
@@ -37,18 +37,14 @@
  * \todo Perhaps expose a routine for shuffling the buffers. */
 
 #include "config.h"
-#include <sys/types.h>
-
 #include <assert.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <errno.h>
 #include <string.h>
-
 #include "librsync.h"
-#include "trace.h"
 #include "buf.h"
 #include "job.h"
+#include "trace.h"
 #include "util.h"
 
 struct rs_filebuf {
@@ -105,7 +101,7 @@ rs_result rs_infilebuf_fill(rs_job_t *job, rs_buffers_t *buf, void *opaque)
         return RS_DONE;
 
     len = fread(fb->buf, 1, fb->buf_len, f);
-    if (len <= 0) {
+    if (len == 0) {
         /* This will happen if file size is a multiple of input block len */
         if (feof(f)) {
             rs_trace("seen end of file on input");
