@@ -21,27 +21,27 @@
  */
 
 #include "config.h"
-
 #include <assert.h>
 #include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <errno.h>
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
-#include <stdio.h>
 #ifdef HAVE_FCNTL_H
 #  include <fcntl.h>
 #endif
+#ifdef HAVE_SYS_TYPES_H
+#  include <sys/types.h>
+#endif
 #ifdef HAVE_SYS_FILE_H
 #  include <sys/file.h>
 #endif
 #ifdef HAVE_SYS_STAT_H
 #  include <sys/stat.h>
 #endif
-#include <string.h>
-#include <errno.h>
-
 #include "librsync.h"
-#include "fileutil.h"
 #include "trace.h"
 
 /* Use fseeko64, _fseeki64, or fseeko for long files if they exist. */
@@ -73,13 +73,6 @@
 #  define fileno(f) _fileno((f))
 #endif
 
-/** Open a file with special handling for '-' or unspecified filenames.
- *
- * \param filename - The filename to open.
- *
- * \param mode - fopen style mode string.
- *
- * \param force - bool to force overwriting of existing files. */
 FILE *rs_file_open(char const *filename, char const *mode, int force)
 {
     FILE *f;
@@ -126,12 +119,12 @@ int rs_file_close(FILE *f)
     return fclose(f);
 }
 
-void rs_get_filesize(FILE *f, rs_long_t *size)
+rs_long_t rs_file_size(FILE *f)
 {
     struct stat st;
-    if (size && (fstat(fileno(f), &st) == 0) && (S_ISREG(st.st_mode))) {
-        *size = st.st_size;
-    }
+    if ((fstat(fileno(f), &st) == 0) && (S_ISREG(st.st_mode)))
+        return st.st_size;
+    return -1;
 }
 
 rs_result rs_file_copy_cb(void *arg, rs_long_t pos, size_t *len, void **buf)
