@@ -20,17 +20,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/** \file prototab.c Delta file commands.
+/** \file prototab.c
+ * Delta file commands.
  *
  * This file defines an array mapping command IDs to the operation kind,
  * implied literal value, and length of the first and second parameters. The
  * implied value is only used if the first parameter length is zero. */
 
 #include "config.h"
-
-#include <stdlib.h>
-#include <stdio.h>
-
 #include "librsync.h"
 #include "command.h"
 #include "prototab.h"
