@@ -26,7 +26,8 @@
                                |              -- Harold Bloom
                                */
 
-/** \file rdiff.c -- Command-line network-delta tool.
+/** \file rdiff.c
+ * Command-line network-delta tool.
  *
  * \todo Add a -z option to gzip/gunzip patches. This would be somewhat useful,
  * but more importantly a good test of the streaming API. Also add -I for
@@ -43,32 +44,15 @@
  * \todo Add an option for delta to check whether the files are identical. */
 
 #include "config.h"
-
 #include <stdlib.h>
-#include <stdio.h>
+#include <stdarg.h>
 #include <string.h>
-#include <fcntl.h>
 #include <popt.h>
-
-#ifdef HAVE_ZLIB_H
-#  include <zlib.h>
-#endif
-
-#ifdef HAVE_BZLIB_H
-#  include <bzlib.h>
-#endif
-
 #include "librsync.h"
-#include "fileutil.h"
-#include "util.h"
-#include "trace.h"
 #include "isprefix.h"
-#include "sumset.h"
 
-#define PROGRAM "rdiff"
-
-static size_t block_len = RS_DEFAULT_BLOCK_LEN;
-static size_t strong_len = 0;
+static int block_len = 0;
+static int strong_len = 0;
 
 static int show_stats = 0;
 
@@ -80,46 +64,32 @@ enum {
     OPT_GZIP = 1069, OPT_BZIP2
 };
 
-extern int rs_roll_paranoia;
 char *rs_hash_name;
+char *rs_rollsum_name;
 
-const struct poptOption opts[] = {
-    {"verbose", 'v', POPT_ARG_NONE, 0, 'v'},
-    {"version", 'V', POPT_ARG_NONE, 0, 'V'},
-    {"input-size", 'I', POPT_ARG_INT, &rs_inbuflen},
-    {"output-size", 'O', POPT_ARG_INT, &rs_outbuflen},
-    {"hash", 'H', POPT_ARG_STRING, &rs_hash_name},
-    {"help", '?', POPT_ARG_NONE, 0, 'h'},
-    {0, 'h', POPT_ARG_NONE, 0, 'h'},
-    {"block-size", 'b', POPT_ARG_INT, &block_len},
-    {"sum-size", 'S', POPT_ARG_INT, &strong_len},
-    {"statistics", 's', POPT_ARG_NONE, &show_stats},
-    {"stats", 0, POPT_ARG_NONE, &show_stats},
-    {"gzip", 'z', POPT_ARG_NONE, 0, OPT_GZIP},
-    {"bzip2", 'i', POPT_ARG_NONE, 0, OPT_BZIP2},
-    {"force", 'f', POPT_ARG_NONE, &file_force},
-    {"paranoia", 0, POPT_ARG_NONE, &rs_roll_paranoia},
-    {0}
-};
-
-static void rdiff_usage(const char *error)
+static void rdiff_usage(const char *error, ...)
 {
-    fprintf(stderr, "%s\n" "Try `%s --help' for more information.\n", error,
-            PROGRAM);
+    va_list va;
+    char buf[256];
+
+    va_start(va, error);
+    vsnprintf(buf, sizeof(buf), error, va);
+    va_end(va);
+    fprintf(stderr, "rdiff: %s\n\nTry `rdiff --help' for more information.\n",
+            buf);
 }
 
 static void rdiff_no_more_args(poptContext opcon)
 {
     if (poptGetArg(opcon)) {
-        rdiff_usage("rdiff: too many arguments");
+        rdiff_usage("Too many arguments.");
         exit(RS_SYNTAX_ERROR);
     }
 }
 
 static void bad_option(poptContext opcon, int error)
 {
-    fprintf(stderr, "%s: %s: %s", PROGRAM, poptStrerror(error),
-            poptBadOption(opcon, 0));
+    rdiff_usage("%s: %s", poptStrerror(error), poptBadOption(opcon, 0));
     exit(RS_SYNTAX_ERROR);
 }
 
@@ -136,10 +106,10 @@ static void help(void)
            "  -f, --force               Force overwriting existing files\n"
            "Signature generation options:\n"
            "  -H, --hash=ALG            Hash algorithm: blake2 (default), md4\n"
+           "  -R, --rollsum=ALG         Rollsum algorithm: rabinkarp (default), rollsum\n"
            "Delta-encoding options:\n"
-           "  -b, --block-size=BYTES    Signature block size\n"
-           "  -S, --sum-size=BYTES      Set signature strength\n"
-           "      --paranoia            Verify all rolling checksums\n"
+           "  -b, --block-size=BYTES    Signature block size, 0 (default) for recommended\n"
+           "  -S, --sum-size=BYTES      Signature strength, 0 (default) for max, -1 for min\n"
            "IO options:\n" "  -I, --input-size=BYTES    Input buffer size\n"
            "  -O, --output-size=BYTES   Output buffer size\n"
            "  -z, --gzip[=LEVEL]        gzip-compress deltas\n"
@@ -191,7 +161,7 @@ static void rdiff_options(poptContext opcon)
             exit(RS_DONE);
         case 'v':
             if (!rs_supports_trace()) {
-                rs_error("library does not support trace");
+                fprintf(stderr, "rdiff: Library does not support trace.\n");
             }
             rs_trace_set_level(RS_LOG_DEBUG);
             break;
@@ -210,7 +180,7 @@ static void rdiff_options(poptContext opcon)
                 else
                     bzip2_level = 9;    /* demand the best */
             }
-            rs_error("sorry, compression is not really implemented yet");
+            rdiff_usage("Sorry, compression is not implemented yet.");
             exit(RS_UNIMPLEMENTED);
 
         default:
@@ -235,15 +205,17 @@ static rs_result rdiff_sig(poptContext opcon)
     if (!rs_hash_name || !strcmp(rs_hash_name, "blake2")) {
         sig_magic = RS_BLAKE2_SIG_MAGIC;
     } else if (!strcmp(rs_hash_name, "md4")) {
-        /* By default, for compatibility with rdiff 0.9.8 and before, mdfour
-           sums are truncated to only 8 bytes, making them even weaker, but
-           making the signature file shorter. */
-        if (!strong_len)
-            strong_len = 8;
         sig_magic = RS_MD4_SIG_MAGIC;
     } else {
-        rs_error("unknown hash algorithm %s", rs_hash_name);
-        return RS_PARAM_ERROR;
+        rdiff_usage("Unknown hash algorithm '%s'.", rs_hash_name);
+        exit(RS_SYNTAX_ERROR);
+    }
+    if (!rs_rollsum_name || !strcmp(rs_rollsum_name, "rabinkarp")) {
+        /* The RabinKarp magics are 0x10 greater than the rollsum magics. */
+        sig_magic += 0x10;
+    } else if (strcmp(rs_rollsum_name, "rollsum")) {
+        rdiff_usage("Unknown rollsum algorithm '%s'.", rs_rollsum_name);
+        exit(RS_SYNTAX_ERROR);
     }
 
     result =
@@ -272,7 +244,7 @@ static rs_result rdiff_delta(poptContext opcon)
     if (!(sig_name = poptGetArg(opcon))) {
         rdiff_usage("Usage for delta: "
                     "rdiff [OPTIONS] delta SIGNATURE [NEWFILE [DELTA]]");
-        return RS_SYNTAX_ERROR;
+        exit(RS_SYNTAX_ERROR);
     }
 
     sig_file = rs_file_open(sig_name, "rb", file_force);
@@ -318,7 +290,7 @@ static rs_result rdiff_patch(poptContext opcon)
     if (!(basis_name = poptGetArg(opcon))) {
         rdiff_usage("Usage for patch: "
                     "rdiff [OPTIONS] patch BASIS [DELTA [NEW]]");
-        return RS_SYNTAX_ERROR;
+        exit(RS_SYNTAX_ERROR);
     }
 
     basis_file = rs_file_open(basis_name, "rb", file_force);
@@ -353,21 +325,41 @@ static rs_result rdiff_action(poptContext opcon)
         return rdiff_patch(opcon);
 
     rdiff_usage
-        ("rdiff: You must specify an action: `signature', `delta', or `patch'.");
-    return RS_SYNTAX_ERROR;
+        ("You must specify an action: `signature', `delta', or `patch'.");
+    exit(RS_SYNTAX_ERROR);
 }
 
 int main(const int argc, const char *argv[])
 {
+    /* Initialize opts at runtime to avoid unknown address values. */
+    const struct poptOption opts[] = {
+        {"verbose", 'v', POPT_ARG_NONE, 0, 'v'},
+        {"version", 'V', POPT_ARG_NONE, 0, 'V'},
+        {"input-size", 'I', POPT_ARG_INT, &rs_inbuflen},
+        {"output-size", 'O', POPT_ARG_INT, &rs_outbuflen},
+        {"hash", 'H', POPT_ARG_STRING, &rs_hash_name},
+        {"rollsum", 'R', POPT_ARG_STRING, &rs_rollsum_name},
+        {"help", '?', POPT_ARG_NONE, 0, 'h'},
+        {0, 'h', POPT_ARG_NONE, 0, 'h'},
+        {"block-size", 'b', POPT_ARG_INT, &block_len},
+        {"sum-size", 'S', POPT_ARG_INT, &strong_len},
+        {"statistics", 's', POPT_ARG_NONE, &show_stats},
+        {"stats", 0, POPT_ARG_NONE, &show_stats},
+        {"gzip", 'z', POPT_ARG_NONE, 0, OPT_GZIP},
+        {"bzip2", 'i', POPT_ARG_NONE, 0, OPT_BZIP2},
+        {"force", 'f', POPT_ARG_NONE, &file_force},
+        {0}
+    };
+
     poptContext opcon;
     rs_result result;
 
-    opcon = poptGetContext(PROGRAM, argc, argv, opts, 0);
+    opcon = poptGetContext("rdiff", argc, argv, opts, 0);
     rdiff_options(opcon);
     result = rdiff_action(opcon);
 
     if (result != RS_DONE)
-        rs_log(RS_LOG_ERR | RS_LOG_NONAME, "%s", rs_strerror(result));
+        fprintf(stderr, "rdiff: Failed, %s.\n", rs_strerror(result));
 
     poptFreeContext(opcon);
     return result;
