@@ -17,23 +17,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/** \file stats.c stats reporting functions.
+/** \file stats.c
+ * stats reporting functions.
  *
  * \todo Other things to show in statistics: number of input and output bytes,
  * number of times we blocked waiting for input or output, number of blocks. */
 
 #include "config.h"
-
-#include <stdlib.h>
 #include <stdio.h>
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#endif
-#ifdef HAVE_SYS_FILE_H
-#  include <sys/file.h>
-#endif
-#include <string.h>
-
 #include "librsync.h"
 #include "trace.h"
 
