@@ -52,18 +52,19 @@ struct rs_signature {
  *
  * \param *sig the signature to initialize.
  *
- * \param magic the signature magic value. Must be set to a valid magic value.
+ * \param magic - the magic type to use (0 for "recommended").
  *
- * \param block_len the block size to use. Must be > 0.
+ * \param block_len - the block length to use (0 for "recommended").
  *
- * \param strong_len the strongsum size to use. Must be <= the max strongsum
- * size for the strongsum type indicated by the magic value. Use 0 to use the
- * recommended size for the provided magic value.
+ * \param strong_len - the strongsum length to use (0 for "maximum", -1 for
+ * "minimum"). Must be <= the max strongsum size for the strongsum type
+ * indicated by the magic value.
  *
- * \param sig_fsize signature file size to preallocate required storage for.
- * Use 0 if size is unknown. */
-rs_result rs_signature_init(rs_signature_t *sig, int magic, int block_len,
-                            int strong_len, rs_long_t sig_fsize);
+ * \param sig_fsize - the signature file size (-1 for "unknown"). Used to
+ * preallocate required storage. */
+rs_result rs_signature_init(rs_signature_t *sig, rs_magic_number magic,
+                            size_t block_len, size_t strong_len,
+                            rs_long_t sig_fsize);
 
 /** Destroy an rs_signature instance. */
 void rs_signature_done(rs_signature_t *sig);
@@ -77,30 +78,57 @@ rs_block_sig_t *rs_signature_add_block(rs_signature_t *sig,
 rs_long_t rs_signature_find_match(rs_signature_t *sig, rs_weak_sum_t weak_sum,
                                   void const *buf, size_t len);
 
-/** Log the rs_signature_find_match() stats. */
-void rs_signature_log_stats(rs_signature_t const *sig);
+/** Assert that rs_sig_args() args for rs_signature_init() are valid.
+ *
+ * We don't use a static inline function here so that assert failure output
+ * points at where rs_sig_args_check() was called from. */
+#define rs_sig_args_check(magic, block_len, strong_len) do {\
+    assert(((magic) & 0xffffff00) == (RS_MD4_SIG_MAGIC & 0xffffff00));\
+    assert(((magic) & 0xf0) == 0x30 || ((magic) & 0xf0) == 0x40);\
+    assert((((magic) & 0x0f) == 0x06 &&\
+	    (strong_len) <= RS_MD4_SUM_LENGTH) ||\
+	   (((magic) & 0x0f) == 0x07 &&\
+	    (strong_len) <= RS_BLAKE2_SUM_LENGTH));\
+    assert(0 < (block_len));\
+    assert(0 < (strong_len) && (strong_len) <= RS_MAX_STRONG_SUM_LENGTH);\
+} while (0)
 
 /** Assert that a signature is valid.
  *
  * We don't use a static inline function here so that assert failure output
  * points at where rs_signature_check() was called from. */
 #define rs_signature_check(sig) do {\
-    assert(((sig)->magic == RS_BLAKE2_SIG_MAGIC && (sig)->strong_sum_len <= RS_BLAKE2_SUM_LENGTH)\
-           || ((sig)->magic == RS_MD4_SIG_MAGIC && (sig)->strong_sum_len <= RS_MD4_SUM_LENGTH));\
-    assert(0 < (sig)->block_len);\
-    assert(0 < (sig)->strong_sum_len && (sig)->strong_sum_len <= RS_MAX_STRONG_SUM_LENGTH);\
+    rs_sig_args_check((sig)->magic, (sig)->block_len, (sig)->strong_sum_len);\
     assert(0 <= (sig)->count && (sig)->count <= (sig)->size);\
     assert(!(sig)->hashtable || (sig)->hashtable->count <= (sig)->count);\
 } while (0)
 
+/** Get the weaksum kind for a signature. */
+static inline weaksum_kind_t rs_signature_weaksum_kind(rs_signature_t const
+                                                       *sig)
+{
+    return (sig->magic & 0xf0) == 0x30 ? RS_ROLLSUM : RS_RABINKARP;
+}
+
+/** Get the strongsum kind for a signature. */
+static inline strongsum_kind_t rs_signature_strongsum_kind(rs_signature_t const
+                                                           *sig)
+{
+    return (sig->magic & 0x0f) == 0x06 ? RS_MD4 : RS_BLAKE2;
+}
+
+/** Calculate the weak sum of a buffer. */
+static inline rs_weak_sum_t rs_signature_calc_weak_sum(rs_signature_t const
+                                                       *sig, void const *buf,
+                                                       size_t len)
+{
+    return rs_calc_weak_sum(rs_signature_weaksum_kind(sig), buf, len);
+}
+
 /** Calculate the strong sum of a buffer. */
 static inline void rs_signature_calc_strong_sum(rs_signature_t const *sig,
                                                 void const *buf, size_t len,
                                                 rs_strong_sum_t *sum)
 {
-    if (sig->magic == RS_BLAKE2_SIG_MAGIC) {
-        rs_calc_blake2_sum(buf, len, sum);
-    } else {
-        rs_calc_md4_sum(buf, len, sum);
-    }
+    rs_calc_strong_sum(rs_signature_strongsum_kind(sig), buf, len, sum);
 }
