@@ -26,7 +26,6 @@
 #include "config.h"
 #include <stdlib.h>
 #include <string.h>
-
 #include "librsync.h"
 #include "util.h"
 #include "trace.h"
@@ -67,3 +66,29 @@ void *rs_realloc(void *ptr, size_t size, char const *name)
     }
     return p;
 }
+
+int rs_long_ln2(rs_long_t v)
+{
+    int n;
+
+    /* Count the number of shifts to zero v. */
+    for (n = 0; (v >>= 1); n++) ;
+    return n;
+}
+
+int rs_long_sqrt(rs_long_t v)
+{
+    rs_long_t n, b;
+
+    /* Find the most significant bit of the root. */
+    for (b = 1, n = v; (n >>= 2); b <<= 1) ;
+    /* Walk down the bits of the root. */
+    for (n = 0; b; b >>= 1) {
+        /* Set the bit in the answer n. */
+        n |= b;
+        /* If n^2 is too big, clear the bit. */
+        if (n * n > v)
+            n ^= b;
+    }
+    return n;
+}
