@@ -28,28 +28,18 @@
                                */
 
 #include "config.h"
-
 #include <assert.h>
 #include <stdlib.h>
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#endif
 #include <stdio.h>
 #include <string.h>
-#include <errno.h>
-
 #include "librsync.h"
-
-#include "trace.h"
-#include "fileutil.h"
+#include "whole.h"
 #include "sumset.h"
 #include "job.h"
 #include "buf.h"
-#include "whole.h"
-#include "util.h"
 
 /** Whole file IO buffer sizes. */
-int rs_inbuflen = 0, rs_outbuflen = 0;
+LIBRSYNC_EXPORT int rs_inbuflen = 0, rs_outbuflen = 0;
 
 /** Run a job continuously, with input to/from the two specified files.
  *
@@ -90,16 +80,21 @@ rs_result rs_whole_run(rs_job_t *job, FILE *in_file, FILE *out_file,
     return result;
 }
 
-rs_result rs_sig_file(FILE *old_file, FILE *sig_file, size_t new_block_len,
+rs_result rs_sig_file(FILE *old_file, FILE *sig_file, size_t block_len,
                       size_t strong_len, rs_magic_number sig_magic,
                       rs_stats_t *stats)
 {
     rs_job_t *job;
     rs_result r;
+    rs_long_t old_fsize = rs_file_size(old_file);
 
-    job = rs_sig_begin(new_block_len, strong_len, sig_magic);
+    if ((r =
+         rs_sig_args(old_fsize, &sig_magic, &block_len,
+                     &strong_len)) != RS_DONE)
+        return r;
+    job = rs_sig_begin(block_len, strong_len, sig_magic);
     /* Size inbuf for 4 blocks, outbuf for header + 4 blocksums. */
-    r = rs_whole_run(job, old_file, sig_file, 4 * new_block_len,
+    r = rs_whole_run(job, old_file, sig_file, 4 * block_len,
                      12 + 4 * (4 + strong_len));
     if (stats)
         memcpy(stats, &job->stats, sizeof *stats);
@@ -115,8 +110,8 @@ rs_result rs_loadsig_file(FILE *sig_file, rs_signature_t **sumset,
     rs_result r;
 
     job = rs_loadsig_begin(sumset);
-    /* Estimate a number of signatures by file size */
-    rs_get_filesize(sig_file, &job->sig_fsize);
+    /* Set filesize used to estimate signature size. */
+    job->sig_fsize = rs_file_size(sig_file);
     /* Size inbuf for 1024x 16 byte blocksums. */
     r = rs_whole_run(job, sig_file, NULL, 1024 * 16, 0);
     if (stats)
